@@ -21,17 +21,21 @@ https://github.com/GeodeZYX/GeodeZYX-Toolbox_v4
 ########## BEGIN IMPORT ##########
 #### External modules
 import numpy as np
-import scipy
-from pyorbital import astronomy
+#import scipy
+#from pyorbital import astronomy
 import re
 
 #### geodeZYX modules
 from geodezyx import utils
 
+#### Import the logger
+import logging
+log = logging.getLogger(__name__)
+
 #### Import star style
-from geodezyx import *                   # Import the GeodeZYX modules
-from geodezyx.externlib import *         # Import the external modules
-from geodezyx.megalib.megalib import *   # Import the legacy modules names
+# from geodezyx import *                   # Import the GeodeZYX modules
+# from geodezyx.externlib import *         # Import the external modules
+# from geodezyx.megalib.megalib import *   # Import the legacy modules names
 
 ##########  END IMPORT  ##########
 
@@ -62,6 +66,7 @@ def dms2dec_num(deg,minn=0,sec=0):
     -------
     dd_float : float
         Decimal degree Angle
+        
     """
     return deg + minn * (1./60.) +  sec * (1./3600.)
 
@@ -82,6 +87,7 @@ def deg_dec2dms(deg_in,only_dm=False):
     -------
     deg , minu , sec : numpy.array of float
         3 arrays for Degrees, Minutes, Seconds
+        
     """
     deg              = np.floor(deg_in)
     decimal_part     = deg_in - deg 
@@ -125,10 +131,11 @@ def dms2dec(dms_str , onlyDM=False):
     -------
     dd_float : float
         Decimal degree Angle
+        
     """
     
     if not onlyDM:
-        print("WARN : DMS mode not well implemented yet !!! ")
+        log.warning("DMS mode not well implemented yet !!! ")
     
     
     dms_str = dms_str.strip()
@@ -153,7 +160,6 @@ def dms2dec(dms_str , onlyDM=False):
             lis.remove(e)
 
     lis = [float(e) for e in lis]
-    print(lis)
 
     deg = lis[0]
     minu = lis[1]
@@ -163,7 +169,7 @@ def dms2dec(dms_str , onlyDM=False):
         try:
             sec  = lis[2]
         except IndexError:
-            print("ERR : did you forgot to activate the DM only mode ? ;) ?")
+            log.error("did you forgot to activate the DM only mode ? ;) ?")
             return None
 
     dd_float = sign * (deg + minu / 60. + sec / 3600.)
@@ -177,6 +183,7 @@ def arcsec2deg(arcsec_in):
     Arcsecond => Degrees
     
     NB : Not really useful, should be avoided
+    
     """
         
     return arcsec_in / 3600.
@@ -189,6 +196,7 @@ def deg2arcsec(deg_in):
     Degrees => Arcsecond
     
     NB : Not really useful, should be avoided
+    
     """
     return deg_in * 3600.
 
@@ -202,6 +210,7 @@ def angle2equivalent_earth_radius(angle_in,angtype='deg',
     Useful to determine metric varations in latitude
     
     angle can be : "deg", "rad", "mas"
+    
     """
     earth_circum = earth_radius * 2 * np.pi
     if angtype == "deg":
@@ -227,6 +236,7 @@ def angle2equivalent_earth_parallel(angle_in,latitude_in,
      the radius of the parallel)
     
     angle can be : "deg", "rad", "mas"
+    
     """
     
     if angtype == "deg":
@@ -238,9 +248,7 @@ def angle2equivalent_earth_parallel(angle_in,latitude_in,
     
     
     parallel_radius = np.cos(latitude_rad) * earth_radius
-    
-    print("AAAAAAAAAAAAAA",parallel_radius)
-    
+        
     return angle2equivalent_earth_radius(angle_in,angtype,
                                          parallel_radius)
         
@@ -249,6 +257,7 @@ def anglesfromvects(xa,ya,xb,yb,angtype='deg'):
     Determines the angle between the points A(xa,ya) and B(xb,yb)
     
     angle can be : "deg", "rad"
+    
     """
     A = np.array([xa,ya])
     B = np.array([xb,yb])
@@ -261,7 +270,7 @@ def anglesfromvects(xa,ya,xb,yb,angtype='deg'):
     elif angtype == 'rad':
         return a
     else:
-        print('ERR : angfromvects : mauvais angtype')
+        log.error('ERR : angfromvects : mauvais angtype')
 
 def angle_interpolation_quick(A,B,w):
     """
@@ -270,10 +279,12 @@ def angle_interpolation_quick(A,B,w):
     the parameter w € [0,1] define the interpoled angle C(w)
     where C(w=0) = A  &  C(w=1) = B
 
-    Source
-    ------
+    References
+    ----------
     https://stackoverflow.com/questions/2708476/rotation-interpolation
+    
     """
+
     CS = (1-w)*np.cos(A) + w*np.cos(B)
     SN = (1-w)*np.sin(A) + w*np.sin(B)
     C = np.atan2(SN,CS)
@@ -285,10 +296,12 @@ def angle_from_3_pts(p1,p2,p3):
     Gives angle between 3 points
     p3 is the vertex (sommet)
     
-    Source
-    ------
+    References
+    ----------
     http://www.les-mathematiques.net/phorum/read.php?8,596072,596231
+    
     """
+    
 
     p1,p2,p3 = [np.array(e) for e in (p1,p2,p3)]
     x1 , y1 = p1
