@@ -26,8 +26,8 @@ import math
 import numpy as np
 import os 
 import pandas as pd
-import scipy
-from scipy.spatial.transform import Rotation
+#import scipy
+#from scipy.spatial.transform import Rotation
 import string
 import struct
 import subprocess
@@ -35,22 +35,25 @@ import re
 import time
 import warnings
 ## Finding day of year
-from datetime import datetime, date
+from datetime import datetime, date 
 
 #### geodeZYX modules
 from geodezyx import utils,stats
 
-#### Import star style
-from geodezyx import *                   # Import the GeodeZYX modules
-from geodezyx.externlib import *         # Import the external modules
-from geodezyx.megalib.megalib import *   # Import the legacy modules names
+### Imported in the corresponding function to avoid cyclic import
+### from geodezyx.conv import conv_interpolators
+from geodezyx.conv import conv_rinex
+### https://stackoverflow.com/questions/1250103/attributeerror-module-object-has-no-attribute
+
+#### Import the logger
+import logging
+log = logging.getLogger(__name__)
+
+
 
 ##########  END IMPORT  ##########
 
 
-
-#import utils.utils as utils
-
 #  _______ _                   _____                              _
 # |__   __(_)                 / ____|                            (_)
 #    | |   _ _ __ ___   ___  | |     ___  _ ____   _____ _ __ ___ _  ___  _ __
@@ -59,137 +62,7 @@ from geodezyx.megalib.megalib import *   # Import the legacy modules names
 #    |_|  |_|_| |_| |_|\___|  \_____\___/|_| |_|\_/ \___|_|  |___/_|\___/|_| |_|
 #
 ### Time conversion
-
-
-def rinex_regex(compressed=True,compiled=False):
-    """
-    Return a regex corresponding to a RINEX name (old convention)
-
-    Parameters
-    ----------
-    compressed : bool
-        return a the regex for a compressed rinex
-
-    compiled : bool
-        return a Python regex object already compliled
-        
-    Returns
-    -------
-    out : string or python's regex
-        a regex
-    """
-    if compressed:
-        regexstr = "....[0-9]{3}.\.[0-9]{2}((d\.(Z)|(gz))|(o)|(d))"
-    else:
-        regexstr = "....[0-9]{3}.\.[0-9]{2}o"
-
-    if compiled:
-        return re.compile(regexstr)
-    else:
-        return regexstr
-
-
-def rinex_regex_new_name(compressed=None,compiled=False):
-    """
-    Return a regex corresponding to a RINEX name (new convention)
-
-    Parameters
-    ----------
-    compressed : bool or None
-        return a the regex for a compressed rinex
-        if None, does not matter (return both compressed or not)
-        
-
-    compiled : bool
-        return a Python regex object already compliled
-        
-    Returns
-    -------
-    out : string or python's regex
-        a regex
-    """
-    if compressed:
-        regexstr = ".{4}[0-9]{2}.{3}_(R|S|U)_[0-9]{11}_[0-9]{2}\w_[0-9]{2}\w_\w{2}\.\w{3}\.gz"
-    elif compressed is None:
-        regexstr = ".{4}[0-9]{2}.{3}_(R|S|U)_[0-9]{11}_[0-9]{2}\w_[0-9]{2}\w_\w{2}\.\w{3}(\.gz)?"        
-    else:
-        regexstr = ".{4}[0-9]{2}.{3}_(R|S|U)_[0-9]{11}_[0-9]{2}\w_[0-9]{2}\w_\w{2}\.\w{3}"
-
-    if compiled:
-        return re.compile(regexstr)
-    else:
-        return regexstr
-
-
-
-def rinex_regex_new_name_brdc(compressed=None,compiled=False):
-    """
-    Return a regex corresponding to a BROADCAST RINEX name (new convention)
-
-    Parameters
-    ----------
-    compressed : bool or None
-        return a the regex for a compressed rinex
-        if None, does not matter (return both compressed or not)
-        
-
-    compiled : bool
-        return a Python regex object already compliled
-        
-    Returns
-    -------
-    out : string or python's regex
-        a regex
-    """
-    if compressed:
-        regexstr = ".{4}[0-9]{2}.{3}_(R|S|U)_[0-9]{11}_[0-9]{2}\w_\w{2}\.\w{3}\.gz"
-    elif compressed is None:
-        regexstr = ".{4}[0-9]{2}.{3}_(R|S|U)_[0-9]{11}_[0-9]{2}\w_\w{2}\.\w{3}(\.gz)?"        
-    else:
-        regexstr = ".{4}[0-9]{2}.{3}_(R|S|U)_[0-9]{11}_[0-9]{2}\w_\w{2}\.\w{3}"
-
-    if compiled:
-        return re.compile(regexstr)
-    else:
-        return regexstr    
-    
-    
-def rinex_regex_new_name_brdc_gfz_godc(compressed=None,compiled=False):
-    """
-    Return a regex corresponding to a BROADCAST RINEX name (new convention)
-    from the GFZ's GODC archive
-
-    Parameters
-    ----------
-    compressed : bool or None
-        return a the regex for a compressed rinex
-        if None, does not matter (return both compressed or not)
-        
-
-    compiled : bool
-        return a Python regex object already compliled
-        
-    Returns
-    -------
-    out : string or python's regex
-        a regex
-    """
-    ### BRDC00GFZ_00000000_FRO_RX3_MN_20210114_000000_01D_00U_GFZ.rnx
-    if compressed:
-        regexstr = ".{4}[0-9]{2}.{3}_[0-9]{8}_.{3}_.{3}_.{2}_[0-9]{8}_[0-9]{6}_[0-9]{2}\w_[0-9]{2}\w_.{3}.\w{3}\.gz"
-    elif compressed is None:
-        regexstr = ".{4}[0-9]{2}.{3}_[0-9]{8}_.{3}_.{3}_.{2}_[0-9]{8}_[0-9]{6}_[0-9]{2}\w_[0-9]{2}\w_.{3}.\w{3}(\.gz)?"        
-    else:
-        regexstr = ".{4}[0-9]{2}.{3}_[0-9]{8}_.{3}_.{3}_.{2}_[0-9]{8}_[0-9]{6}_[0-9]{2}\w_[0-9]{2}\w_.{3}.\w{3}"
-
-    if compiled:
-        return re.compile(regexstr)
-    else:
-        return regexstr    
-    
-    
-    
-    
+   
 
 def tgipsy2dt(tin):
     """
@@ -248,7 +121,7 @@ def matlab_time2dt(matlab_datenum):
     return python_datetime
 
 
-def round_dt(dtin,round_to,python_dt_out=True):
+def round_dt(dtin,round_to,python_dt_out=True,mode='round'):
     """
     Round a datetime object to any time laps in seconds
     
@@ -273,6 +146,11 @@ def round_dt(dtin,round_to,python_dt_out=True):
         If True, it returns the date as a legacy Python's DateTime.
         If False, it returns a Pandas Timestamp.
         The default is True.
+
+    mode : str
+        define the way you want to round 
+        the values: 'round' (i.e. the nearest), 'floor', 'ceil'
+        The default if 'round'
             
     Returns
     -------  
@@ -294,7 +172,15 @@ def round_dt(dtin,round_to,python_dt_out=True):
         typ=utils.get_type_smart(dtin)
         dtin_use = pd.Series(dtin)
 
-    dtin_out = dtin_use.dt.round(round_to)
+    if mode == 'round':
+        dtin_out = dtin_use.dt.round(round_to)
+    elif mode == 'ceil':
+        dtin_out = dtin_use.dt.ceil(round_to)
+    elif mode == 'floor':
+        dtin_out = dtin_use.dt.floor(round_to)
+    else:
+        log.err("check mode value: 'round', 'floor', 'ceil'")
+        raise Exception
     
     if python_dt_out:
         dtin_out.dt.to_pydatetime()
@@ -471,7 +357,7 @@ def ymdhms2dt(y=0,mo=0,d=0,h=0,mi=0,s=0,ms=0):
             ms_from_s  = (s - np.floor(s)) * 10**6
             if ms_from_s != 0:
                 if ms != 0:
-                    print('WARN : input sec contains microsecs, given microsec are ignored')
+                    log.warning('input sec contains microsecs, given microsec are ignored')
                 ms = ms_from_s
             return dt.datetime(int(y),int(mo),int(d),int(h),int(mi),int(s),int(ms))
         except:
@@ -662,7 +548,7 @@ def dt2secinday(dtin):
         return typ([dt2secinday(e) for e in dtin])
     else:
         return dtin.hour * 3600 + dtin.minute * 60 + dtin.second
-
+    
 def dt2tuple(dtin):
     return tuple(dtin.timetuple())[:-3]
 
@@ -868,7 +754,9 @@ def dt_utc2dt_ut1_smart(dtin,DF_EOP_in,
         
         ### We also use the interpolator class
         if use_interp1d_obj:
-            IEOP = interp1d_time(DF_EOP.index.values,DF_EOP['UT1-UTC'])
+            from geodezyx.conv import conv_interpolators
+            IEOP = conv_interpolators.interp1d_time(DF_EOP.index.values,
+                                                    DF_EOP['UT1-UTC'])
         else:
             IEOP = None
         
@@ -1064,10 +952,10 @@ def gpstime2dt(gpsweek,gpsdow_or_seconds,dow_input = True,
     
     if utils.is_iterable(gpsweek):
         typ=utils.get_type_smart(gpsweek)
-        return typ([gpstime2dt(w,ds,dow_input,output_time_scale) for w,ds in zip(gpsweek,gpsdow_or_seconds)])
+        return typ([gpstime2dt(w,ds,dow_input,output_time_scale = output_time_scale) for w,ds in zip(gpsweek,gpsdow_or_seconds)])
     else:
         if dow_input:
-            gpsseconds = gpsdow_or_seconds * 86400 + 86400*.5 # so we are around noon
+            gpsseconds = gpsdow_or_seconds * 86400. + 86400.*.5 # so we are around noon
         else:
             gpsseconds = gpsdow_or_seconds
     
@@ -1104,7 +992,7 @@ def gpstime2dt(gpsweek,gpsdow_or_seconds,dow_input = True,
         return final_time
 
 
-def gpsweek_decimal2dt(gpsweekdec_in):
+def gpsweek_decimal2dt(gpsweekdec_in, output_time_scale = 'utc'):
     """
     Time representation conversion
     
@@ -1114,6 +1002,8 @@ def gpsweek_decimal2dt(gpsweekdec_in):
     ----------
     gpsweekdec_in : float or list/numpy.array of float
         GPS week in decimal form.
+    output_time_scale : str
+        gives the wished time scale : "utc", "tai", "gps"
 
     Returns
     -------
@@ -1123,13 +1013,15 @@ def gpsweek_decimal2dt(gpsweekdec_in):
     """
     if utils.is_iterable(gpsweekdec_in):
         typ=utils.get_type_smart(gpsweekdec_in)
-        return typ([gpsweek_decimal2dt(e) for e in gpsweekdec_in])
+        return typ([gpsweek_decimal2dt(e,output_time_scale = output_time_scale) for e in gpsweekdec_in])
     else:
         week_floor    = np.floor(gpsweekdec_in)
         week_dec_part = gpsweekdec_in - week_floor 
         
+
         dt_out = gpstime2dt(week_floor,week_dec_part * 7 *86400,
-                            dow_input = False)
+                            dow_input = False, 
+                            output_time_scale = output_time_scale)
         return dt_out
     
 
@@ -1243,7 +1135,22 @@ def dt2year_decimal(dtin):
         typ=utils.get_type_smart(dtin)
         return typ([dt2year_decimal(e) for e in dtin])
     else:
-        return toYearFraction(dtin)
+        
+        def sinceEpoch(date): # returns seconds since epoch
+            return time.mktime(date.timetuple())
+       
+        date_in = dtin
+        
+        year = date_in.year
+        startOfThisYear = dt.datetime(year=year, month=1, day=1)
+        startOfNextYear = dt.datetime(year=year+1, month=1, day=1)
+        
+        yearElapsed = sinceEpoch(date_in) - sinceEpoch(startOfThisYear)
+        yearDuration = sinceEpoch(startOfNextYear) - sinceEpoch(startOfThisYear)
+        
+        fraction = yearElapsed/yearDuration
+        
+        return date_in.year + fraction
 
 def date_string_2_dt(strin):
     """
@@ -1383,7 +1290,7 @@ def MJD2dt(mjd_in,seconds=None,round_to='1s'):
         typ=utils.get_type_smart(mjd_in)
         if seconds:
             if len(seconds) != len(mjd_in):
-                print("ERR : MJD2dt : len(seconds) != len(mjd_in) !!")
+                log.error("len(seconds) != len(mjd_in) !!")
                 raise Exception
         else:
             seconds = np.zeros(len(mjd_in))
@@ -1468,7 +1375,7 @@ def rinexname2dt(rinexpath):
     """
     Time representation conversion
     
-    RINEX Name (old or new naming convention)  => Python's Datetime
+    RINEX Name (short or long naming convention)  => Python's Datetime
     
     Extract the date in a RINEX name
 
@@ -1486,9 +1393,8 @@ def rinexname2dt(rinexpath):
     rinexname = os.path.basename(rinexpath)
     #rinexname = rinexpath
         
-    
-    ##### NEW rinex name
-    if re.search(rinex_regex_new_name(),rinexname) or re.search(rinex_regex_new_name_brdc(),rinexname):
+    ##### LONG rinex name
+    if re.search(conv_rinex.rinex_regex_long_name(),rinexname) or re.search(conv_rinex.rinex_regex_long_name_brdc(),rinexname):
         date_str = rinexname.split("_")[2]
         yyyy = int(date_str[:4])
         doy  = int(date_str[4:7])        
@@ -1497,9 +1403,8 @@ def rinexname2dt(rinexpath):
         dt_out = doy2dt(yyyy,doy) + dt.timedelta(seconds=hh*3600 + mm*60)
         return dt_out 
 
-    ##### NEW rinex name -- GFZ's GODC internal name
-    ###### OBS RINEX for GFZ GODC not implemented yet !!!!
-    if re.search(rinex_regex_new_name_brdc_gfz_godc(),rinexname): 
+    ##### LONG rinex name -- GFZ's GODC internal name
+    if re.search(conv_rinex.rinex_regex_long_name_gfz_godc(),rinexname): 
         date_str = rinexname.split("_")[5]
         time_str = rinexname.split("_")[6]
         yyyy = int(date_str[:4])
@@ -1514,10 +1419,9 @@ def rinexname2dt(rinexpath):
         
         return dt_out 
     
-    ##### OLD rinex name    
-    elif re.search(rinex_regex(),rinexname):
+    ##### SHORT rinex name
+    elif re.search(conv_rinex.rinex_regex(),rinexname):
         alphabet = list(string.ascii_lowercase)
-    
 
         doy  = int(rinexname[4:7])
         yy   = int(rinexname[9:11])
@@ -1535,7 +1439,7 @@ def rinexname2dt(rinexpath):
         return dt.datetime(year,1,1) + dt.timedelta(days = doy - 1 , seconds = h * 3600)
 
     else:
-        print('ERR: RINEX name is not well formated:',rinexname)
+        log.error('RINEX name is not well formated: %s',rinexname)
         raise Exception
     
 
@@ -1657,17 +1561,146 @@ def statname_dt2rinexname(statname,datein,rnxtype='d.Z',
 
     alphabet = list(string.ascii_lowercase)
 
-    if datein.hour != 0:
+    if session_a_instead_of_daily_session:
         sess = alphabet[datein.hour]
     else:
-        if session_a_instead_of_daily_session:
-            sess = alphabet[datein.hour]
-        else:
-            sess = '0'
+        sess = '0'
 
     return statname + dt2doy(datein) + sess + '.' + datein.strftime('%y') + rnxtype
 
 
+def statname_dt2rinexname_long(statname,datein,
+                               country="XXX",
+                               data_source="R",
+                               file_period="00U",
+                               data_freq="XXU",
+                               data_type="MO",                               
+                               format_compression='crz.gz',
+                               preset_type=None):
+
+
+    """ 
+    
+    Time representation conversion
+    
+    Python's Datetime (and station name) => RINEX long name convention
+    
+    Create a RINEX name from a station name, date and ancillary parameters
+
+    Parameters
+    ----------
+    statname : string
+        name of the station
+        can be a 4 or 9 char.
+    
+    datein : datetime
+        date of the wished RINEX name
+        
+    country : string
+        optional. the 3char. country code
+        if given, will replace the one in an input 9-char statname
+        default value is "XXX"
+        
+    data_source : str, optional
+        Data Source.
+        R – From Receiver, data using vendor or other software
+        S – From data Stream (RTCM or other)
+        U – Unknown
+        The default is "R".
+        
+    file_period : str, optional
+        File Period
+        15M–15 Minutes
+        01H–1 Hour
+        01D–1 Day
+        01Y–1 Year
+        00U-Unspecified
+        The default is "00U".
+        
+    data_freq : str, optional
+        data frequency. 
+        XXC – 100 Hertz
+        XXZ – Hertz,
+        XXS – Seconds,
+        XXM – Minutes,
+        XXH – Hours,
+        XXD – Days
+        XXU – Unspecified
+        The default is "XXU".
+        
+    data_type : str, optional
+        Two characters represent the data type:
+        GO - GPS Obs.
+        RO - GLONASS Obs.
+        EO - Galileo Obs.
+        JO - QZSS Obs.
+        CO - BDS Obs.
+        IO – NavIC/IRNSS Obs.
+        SO - SBAS Obs.
+        MO - Mixed Obs.
+        GN - Nav. GPS
+        RN - GLONASS Nav.
+        EN - Galileo Nav.
+        JN - QZSS Nav.
+        CN - BDS Nav.
+        IN – NavIC/IRNSS Nav.
+        SN - SBAS Nav.
+        MN – Mixed Nav. (All GNSS
+        Constellations)
+        MM-Meteorological Observation
+
+        The default is "MO".
+        
+    format_compression : string
+        extension of the RINEX ("rnx","crz","crz.gz") ...
+        The default is 'crz.gz'.
+        
+    preset_type : str, optional
+        set the most common data_freq and file_period 
+        for an hourly or daily session. 
+        accept 'daily' or 'hourly' values.
+        The default is None.
+
+
+    Returns
+    -------
+    out_rnx_name : str
+        The name of the RINEX.
+
+    """
+        
+    if not len(statname) in (4,9):
+        log.error("statname not 4 or 9 chars")
+        raise Exception
+    
+    if len(statname) == 4:
+        statname_ok = statname + "00" + country
+    elif len(statname) == 9 and country != "XXX":
+        statname_ok = statname[:4] + "00" + country
+    else:
+        statname_ok = statname
+        
+        
+    if preset_type == "daily":
+        file_period="01D"
+        data_freq="30S"     
+                
+    elif preset_type == "hourly":
+        file_period="01H"
+        data_freq="01S"     
+        
+        
+    date_ok = datein.strftime('%Y') +  dt2doy(datein) + datein.strftime('%H%M')
+    period_freq_ok = "_" + file_period + "_" + data_freq + "_" + data_type
+    data_source_ok = "_" + data_source + "_"
+    
+    out_rnx_name = statname_ok + data_source_ok + date_ok + period_freq_ok + '.' + format_compression
+    
+    return out_rnx_name
+    
+
+
+
 def datestr_sinex_2_dt(datestrin):
     """
     Time representation conversion
@@ -1837,7 +1870,6 @@ def datestr_gins_filename_2_dt(datestrin):
     
     else:
         #### CASE WHERE THE DATE LOOKS LIKE 00000:00000
-
         yr = int(datestrin[0:2])
         mm = int(datestrin[2:4])
         dd = int(datestrin[4:6])
@@ -1866,8 +1898,87 @@ def datestr_gins_filename_2_dt(datestrin):
         return dt.datetime(year,mm,dd,hh,mmin,ss)
 
 
+def trimble_file2dt(trmfile_in):
+    """
+    Time representation conversion
+    
+    Trimble raw data file => Python's Datetime
+    
+    Trimble file exemple : CASG202101070000A.T02
+        
+    Parameters
+    ----------
+    trmfile_in : string or list/numpy.array of string.
+        Trimble raw data file as string.
+        Can handle several string in an iterable.
+        Will extract the basename of a path.
+    
+    Returns
+    -------
+    dtout : datetime or list of datetime.
+        Datetime(s)
+    """
+    if utils.is_iterable(trmfile_in):
+        typ=utils.get_type_smart(trmfile_in)
+        return typ([trimble_file2dt(e) for e in trmfile_in])
+    else:
+        trmfile = os.path.basename(trmfile_in)
+        year = int(trmfile[4:8])
+        month = int(trmfile[8:10])
+        day = int(trmfile[10:12])
+        hh =  int(trmfile[12:14])
+        mm =  int(trmfile[14:16])
+        
+        return dt.datetime(year,month,day,hh,mm,0)
+    
+    
+        
+def dt2epoch_rnx3(dt_in,epoch_flag=0,nsats=0,rec_clk_offset=0):
+    """
+    Time representation conversion
+    
+    Python's Datetime => RINEX3/4 epoch representation
+    e.g.
+    > 2022 11 29 17 15 25.0000000  0  0       0.000000000000
 
+    Parameters
+    ----------
+    dt_in : datetime or list of datetime.
+        Datetime(s).
+    epoch_flag : int, optional
+        Epoch flag:
+            0 : OK
+            1 : power failure between previous and current epoch
+            >1 : Special event (see RINEX documentation). 
+        The default is 0.
+    nsats : int, optional
+        Number of satellites observed in current epoch. The default is 0.
+    rec_clk_offset : float, optional
+        Receiver clock offset correction (seconds). The default is 0.
 
+    Returns
+    -------
+    epoch_out : str or list of str
+        output RINEX3/4 epoch representation.
+    """
+
+    if utils.is_iterable(dt_in):
+        typ=utils.get_type_smart(dt_in)
+        return typ([dt2epoch_rnx3(e,epoch_flag,nsats,rec_clk_offset) for e in dt_in])
+    
+    else:
+        fmt="> {:4} {:2n} {:2n} {:2n} {:2n}{:11.7f}  {:1n}{:3n}      {:15.12f}"    
+        epoch_out = fmt.format(dt_in.year,
+                               dt_in.month,
+                               dt_in.day,
+                               dt_in.hour,
+                               dt_in.minute,
+                               dt_in.second,
+                               epoch_flag,
+                               nsats,
+                               rec_clk_offset)
+    
+        return epoch_out
 
 
 #### LEAP SECONDS MANAGEMENT
@@ -2364,14 +2475,14 @@ def epo_epos_converter(inp,inp_type="mjd",out_type="yyyy",verbose=False):
     cmd = " ".join(("perl $EPOS8_BIN_TOOLS/SCRIPTS/get_epoch.pl",epo_cmd,inp_cmd,out_cmd))
 
     if verbose:
-        print(cmd)
+        log.debug(cmd)
     
     result = subprocess.run(cmd,shell=True,stdout=subprocess.PIPE,executable='/bin/bash')
             
     out = int(result.stdout.decode('utf-8'))
     
     if verbose:
-        print(out)
+        log.debug(out)
     
     return out
 
@@ -2411,9 +2522,10 @@ def datetime64_numpy2dt(npdt64_in):
     ------
     
     https://stackoverflow.com/questions/13703720/converting-between-datetime-timestamp-and-datetime64
-    """
-    print("WARN: datetime64_numpy2dt is depreciated, use numpy_dt2dt instead")
-    warnings.warn("WARN: datetime64_numpy2dt is depreciated, use numpy_dt2dt instead",DeprecationWarning)
+    """    
+    
+    log.warning("datetime64_numpy2dt is depreciated, use numpy_dt2dt instead")
+    warnings.warn("datetime64_numpy2dt is depreciated, use numpy_dt2dt instead",DeprecationWarning)
 
 
     if utils.is_iterable(npdt64_in):
@@ -2448,8 +2560,8 @@ def numpy_datetime2dt(npdtin):
     https://stackoverflow.com/questions/29753060/how-to-convert-numpy-datetime64-into-datetime/29755657
     """
     
-    print("WARN: numpy_datetime2dt is depreciated, use numpy_dt2dt instead")
-    warnings.warn("WARN: numpy_datetime2dt is depreciated, use numpy_dt2dt instead",DeprecationWarning)
+    log.warning('datetime64_numpy2dt is depreciated, use numpy_dt2dt instead')
+    warnings.warn("numpy_datetime2dt is depreciated, use numpy_dt2dt instead",DeprecationWarning)
     if utils.is_iterable(npdtin):        
         typ=utils.get_type_smart(npdtin)
         return typ([numpy_datetime2dt(e) for e in npdtin])
@@ -2658,10 +2770,10 @@ def gpstime2utc_bad(gpsweek,gpssecs,utc_offset):
     return utc_time
 
 
-def toYearFraction(date):
+def toYearFraction(date_in):
     """
     DISCONTINUED
-    use dt2year_decimal instead (which is the same)
+    use dt2year_decimal instead (does the same)
     """
     #
     # Give the decimal year
@@ -2675,11 +2787,11 @@ def toYearFraction(date):
         return time.mktime(date.timetuple())
     s = sinceEpoch
 
-    year = date.year
+    year = date_in.year
     startOfThisYear = dt(year=year, month=1, day=1)
     startOfNextYear = dt(year=year+1, month=1, day=1)
 
-    yearElapsed = s(date) - s(startOfThisYear)
+    yearElapsed = s(date_in) - s(startOfThisYear)
     yearDuration = s(startOfNextYear) - s(startOfThisYear)
     fraction = yearElapsed/yearDuration
 
@@ -2700,5 +2812,5 @@ def convert_partial_year(number):
     year = int(number)
     d = timedelta(days=(number - year)*(365 + calendar.isleap(year)))
     day_one = datetime(year,1,1)
-    date = d + day_one
-    return date
+    date_out = d + day_one
+    return date_out
