@@ -24,6 +24,7 @@ import dateutil
 import glob
 import numpy as np
 import os 
+import pandas as pd
 import shutil
 import string
 import subprocess
@@ -33,8 +34,202 @@ import re
 from geodezyx import conv
 from geodezyx import utils
 
+#### Import the logger
+import logging
+log = logging.getLogger(__name__)
+
 ##########  END IMPORT  ##########
 
+
+
+def rinexs_table_from_list(rnxs_inp,site9_col=False,round_date=False):
+    """
+    From a simple RINEX list, summarize the data in an ad-hoc DataFrame
+
+    Parameters
+    ----------
+    rnxs_inp : iterable or str
+        if iterable, a list of RINEX files
+        if str, path of an input RINEX list as text file.
+
+    Returns
+    -------
+    DF : Pandas DataFrame
+        A DataFrame with the RINEX info in it.
+    """
+    
+    if utils.is_iterable(rnxs_inp):
+        DF = pd.DataFrame(rnxs_inp,columns=["path"])        
+    else:
+        DF = pd.read_csv(rnxs_inp,names=["path"])        
+    
+    DF["name"]  = DF["path"].apply(os.path.basename) 
+    DF["site4"] = DF["name"].str[:4].str.lower() 
+    
+    if site9_col:
+        DF["site9"] = DF["name"].str[:9].str.lower() 
+        #### set generic 9-char name if 4 char name file
+        BoolNewName = DF["name"].str.match(conv.rinex_regex_long_name())
+        BoolOldName = np.logical_not(BoolNewName)
+        Site9_generic = DF["site4"].str.upper() + "00XXX"
+        DF["site9"].loc[BoolOldName] = Site9_generic[BoolOldName]
+    
+    
+    DF["date"]  = DF["name"].apply(conv.rinexname2dt) 
+    if round_date:
+        DF["date"] = conv.round_dt(DF["date"].values,'1D',True,"floor")
+    DoyYear = DF["date"].apply(conv.dt2doy_year)
+    DF["doy"]   = DoyYear.apply(lambda x:x[0])
+    DF["year"]  = DoyYear.apply(lambda x:x[1])
+    
+    cols = DF.columns.tolist()
+    
+    cols =  cols[1:] + [cols[0]]
+    
+    DF = DF[cols]
+    
+    pd.options.display.max_info_columns = 150
+
+    return DF
+
+def rinex_sats_checker(p_rnx): 
+    """
+    Check the consistency of a RINEX's sat list for each epoch
+    
+    Designed for checking the consistency of IPGP-OVPF corrupted RINEXs
+    RINEX-2 only
+
+    Parameters
+    ----------
+    p_rnx : str
+        input RINEX path.
+
+    Returns
+    -------
+    bad RINEX path or None.
+
+    """
+    
+    import hatanaka
+    
+    if p_rnx.endswith(".Z") or p_rnx.endswith(".gz"):
+        O = hatanaka.decompress(p_rnx)
+        O = str(O)
+        L = O.split("\\n")
+    else:
+        F = open(p_rnx,"r+")
+        L =  F.readlines()
+    
+    iline_bloc = 0
+    nlines_bloc = -1
+    
+    Blocs_stack = []
+    
+    
+    ###### This loop read all lines
+    for l in L:
+        re_epoch = '^ {1,2}([0-9]{1,2} * ){5}'
+        #re_sat="[A-Z][0-9][0-9]"
+        bool_epoch=re.search(re_epoch,l)
+        #bool_sat=re.search(re_sat,l)
+        
+        ### we found an epoch line
+        if bool_epoch:
+            in_epoch = True
+            nsat = int(l[30:32])
+            iline_bloc = 0
+            nlines_bloc = int(np.ceil(nsat / 12))
+            LineBloc = []
+            lineconcat = ""
+            date = read_rnx_epoch_line(l,rnx2=True)
+        
+        ### we read the sat lines based on the number of sat
+        if iline_bloc <= nlines_bloc:
+            LineBloc.append(l[32:].strip())
+            lineconcat = lineconcat + l[32:].strip()
+            iline_bloc += 1
+        
+        ### we stack everything when the sat block is over
+        if iline_bloc == nlines_bloc:
+            in_epoch = False
+            bloc_tuple = (date,nsat,lineconcat)
+            Blocs_stack.append(bloc_tuple)
+            
+            
+    #### we do a DF with all the found line
+    DF = pd.DataFrame(Blocs_stack)
+    
+    DF[3] = None
+    
+    for irow, row in DF.iterrows():
+        nsat = str(row[1])
+        satstr = row[2]
+        re_sat="([A-Z][0-9][0-9]){" + nsat  + "}" 
+        bool_sat=re.search(re_sat,satstr)
+        
+        #### the the right number of sat is found True = Good
+        if bool_sat:
+            DF.iloc[irow,3] = True
+        else:
+            DF.iloc[irow,3] = False
+    
+    
+    if DF[3].sum() != len(DF):
+        return rinex_sats_checker
+    else:
+        return None
+    
+def read_rnx_epoch_line(line,rnx2=True):
+    """
+    read the epoch line of a RINEX (2 or 3)
+    and extract it as a datetime
+
+    Parameters
+    ----------
+    line : string
+        input line, assuming it's a RINEX epoch line.
+    rnx2 : TYPE, optional
+        True if RINEX2, False if RINEX3/4.
+        The default is True.
+
+    Returns
+    -------
+    epochdt : datetime
+        The epoch of the line.
+    """
+    
+    if rnx2:
+        strtidx=0
+    else:
+        strtidx=1
+    fraw = line[strtidx:].split() #fraw est la pour gerer les fracion de sec ...
+    fraw = fraw[0:6]
+    fraw = [float(e) for e in fraw]
+                
+    f = [int(e) for e in fraw]
+    msec = (fraw[5] - np.floor(fraw[5]))
+    msec = np.round(msec,4)
+    msec = int(msec * 10**6)
+    f.append( msec )  # ajour des fractions de sec
+
+    if rnx2:
+        if f[0] < 50:
+            f[0] = f[0] + 2000
+        else:
+            f[0] = f[0] + 1900
+
+    if f[5] == 60: # cas particulier rencontré dans des rinex avec T = 60sec
+        rinex_60sec = True
+        f[5] = 59
+    else:
+        rinex_60sec = False
+
+    epochdt = dt.datetime(*f)
+
+    if rinex_60sec:
+        epochdt = epochdt + dt.timedelta(seconds=1)
+    return  epochdt
+
 #  _____  _____ _   _ ________   __   _____       _ _ _
 # |  __ \|_   _| \ | |  ____\ \ / /  / ____|     | (_) |
 # | |__) | | | |  \| | |__   \ V /  | (___  _ __ | |_| |_ ___ _ __
@@ -70,7 +265,7 @@ def crz2rnx(rinex_path,outdir='',force=True,path_of_crz2rnx='CRZ2RNX'):
     out_rinex_path = os.path.join(outdir,out_rinex_name)
 
     if os.path.isfile(out_rinex_path) and not force:
-        print("INFO : crz2rnx : ", out_rinex_path , 'already exists, skiping ...')
+        log.info( out_rinex_path  + 'already exists, skiping ...')
     else:
         os.chdir(outdir)
         #stream = os.popen(command)
@@ -80,9 +275,9 @@ def crz2rnx(rinex_path,outdir='',force=True,path_of_crz2rnx='CRZ2RNX'):
         status = proc.wait()
 
         if status != 0 or not os.path.isfile(out_rinex_path):
-            print('ERR : crz2rnx : ',out_rinex_path,"not created ! :(")
+            log.info(out_rinex_path + " not created ! :(")
         else:
-            print('INFO : crz2rnx : ',out_rinex_path, 'created :)')
+            log.info(out_rinex_path + ' created :)')
         #    print stream.read()
         os.chdir(curdir)
     return out_rinex_path
@@ -114,10 +309,11 @@ def crz2rnx_bad(crinex_in_path,outdir='',force=True,path_of_crz2rnx='CRZ2RNX'):
     temp_rinex_path = os.path.join(convert_dir,out_rinex_name)
 
     if os.path.isfile(out_rinex_path) and not force:
-        print("INFO : crz2rnx : ", out_rinex_path , 'already exists, skiping ...')
+        log.info( out_rinex_path  + 'already exists, skiping ...')
+
     else:
         stream = os.popen(command)
-        print('output in',outdir)
+        log.info('output in ' + outdir)
         try:
             shutil.move(temp_rinex_path, outdir)
         except:
@@ -148,41 +344,41 @@ def rnx2crz(rinex_path,outdir='',force=True,path_of_rnx2crz='RNX2CRZ'):
     out_rinex_path = os.path.join(outdir,out_rinex_name_d_Z)
 
     if os.path.isfile(out_rinex_path) and not force:
-        print("INFO : rnx2crz : ", out_rinex_path , 'already exists, skiping ...')
+        log.info( out_rinex_path  + 'already exists, skiping ...')
     else:
         os.chdir(outdir)
         stream = os.popen(command)
-        print(command,', output in',outdir)
+        log.info(command + ' output in ' + outdir)
         #    print stream.read()
     os.chdir(curdir)
     return out_rinex_path
 
-def rinex_regex(compressed=True,compiled=False):
-    if compressed:
-        regexstr = "....[0-9]{3}.\.[0-9]{2}((d\.(Z)|(gz))|(o)|(d))"
-    else:
-        regexstr = "....[0-9]{3}.\.[0-9]{2}o"
+# def rinex_regex(compressed=True,compiled=False):
+#     if compressed:
+#         regexstr = "....[0-9]{3}.\.[0-9]{2}((d\.(Z)|(gz))|(o)|(d))"
+#     else:
+#         regexstr = "....[0-9]{3}.\.[0-9]{2}o"
 
-    if compiled:
-        return re.compile(regexstr)
-    else:
-        return regexstr
+#     if compiled:
+#         return re.compile(regexstr)
+#     else:
+#         return regexstr
 
 
-def rinex_regex_new_name(compressed=True,compiled=False):
-    if compressed:
-        regexstr = ".{4}[0-9]{2}.{3}_(R|S|U)_[0-9]{11}_[0-9]{2}\w_[0-9]{2}\w_\w{2}\.\w{3}\.gz"
-    else:
-        regexstr = ".{4}[0-9]{2}.{3}_(R|S|U)_[0-9]{11}_[0-9]{2}\w_[0-9]{2}\w_\w{2}\.\w{3}"
+# def rinex_regex_new_name(compressed=True,compiled=False):
+#     if compressed:
+#         regexstr = ".{4}[0-9]{2}.{3}_(R|S|U)_[0-9]{11}_[0-9]{2}\w_[0-9]{2}\w_\w{2}\.\w{3}\.gz"
+#     else:
+#         regexstr = ".{4}[0-9]{2}.{3}_(R|S|U)_[0-9]{11}_[0-9]{2}\w_[0-9]{2}\w_\w{2}\.\w{3}"
 
-    if compiled:
-        return re.compile(regexstr)
-    else:
-        return regexstr
+#     if compiled:
+#         return re.compile(regexstr)
+#     else:
+#         return regexstr
 
 
 def rinex_read_epoch(input_rinex_path_or_string,interval_out=False,
-                    add_tzinfo=False,out_array=True):
+                    add_tzinfo=False,out_array=True, out_index=False):
     """
     Read the epochs contained in a RINEX File. Can handle RINEX 2 and 3
 
@@ -204,6 +400,10 @@ def rinex_read_epoch(input_rinex_path_or_string,interval_out=False,
         output results as array. 
         The default is True.
 
+    out_index : bool, optional
+        output also the index of the epoch line.
+        The default is False.
+
     Returns
     -------
     array or list
@@ -221,69 +421,40 @@ def rinex_read_epoch(input_rinex_path_or_string,interval_out=False,
     else:
         Finp = input_rinex_path_or_string
 
-
-    for line in Finp:
+    Index_list = []
+    for iline, line in enumerate(Finp):
         epoch_rnx2=re.search('^ {1,2}([0-9]{1,2} * ){5}',line)
         epoch_rnx3=re.search('^>',line)
         
         if epoch_rnx2:
-            fraw = line.split() #fraw est la pour gerer les fracion de sec ...
-            fraw = fraw[0:6]
-            fraw = [float(e) for e in fraw]
-            f = [int(e) for e in fraw]
-            msec = (fraw[5] - np.floor(fraw[5]))
-            msec = np.round(msec,4)
-            msec = int(msec * 10**6)
-            f.append( msec )  # ajour des fractions de sec
-
-            if f[0] < 50:
-                f[0] = f[0] + 2000
-            else:
-                f[0] = f[0] + 1900
-            if f[5] == 60: # cas particulier rencontré dans des rinex avec T = 60sec
-                rinex_60sec = True
-                f[5] = 59
-            else:
-                rinex_60sec = False
             try:
-                epochdt = dt.datetime(*f)
-                if rinex_60sec:
-                    epochdt = epochdt + dt.timedelta(seconds=1)
+                epochdt = read_rnx_epoch_line(line,rnx2=True)
                 epochs_list.append(epochdt)
+                Index_list.append(iline)
             except:
-                print("ERR : rinex_read_epoch : " , f)
+                log.error(line)
+                
         elif epoch_rnx3:
-            fraw = line[1:].split() #fraw est la pour gerer les fracion de sec ...
-            fraw = fraw[0:6]
-            fraw = [float(e) for e in fraw]
-                        
-            f = [int(e) for e in fraw]
-            msec = (fraw[5] - np.floor(fraw[5]))
-            msec = np.round(msec,4)
-            msec = int(msec * 10**6)
-            f.append( msec )  # ajour des fractions de sec
-
-            if f[5] == 60: # cas particulier rencontré dans des rinex avec T = 60sec
-                rinex_60sec = True
-                f[5] = 59
-            else:
-                rinex_60sec = False
             try:
-                epochdt = dt.datetime(*f)
-                if rinex_60sec:
-                    epochdt = epochdt + dt.timedelta(seconds=1)
+                epochdt = read_rnx_epoch_line(line,rnx2=False)
                 epochs_list.append(epochdt)
+                Index_list.append(iline)
             except:
-                print("ERR : rinex_read_epoch : " , f)
-            
+                log.error(line)
                 
     if add_tzinfo:
         epochs_list = [ e.replace(tzinfo=dateutil.tz.tzutc()) for e in epochs_list]
+        
+    if out_index:
+        OUTPUT = [epochs_list,Index_list]
+    else:
+        OUTPUT = epochs_list
 
     if out_array:
-        return np.array(epochs_list)
-    else:
-        return epochs_list
+        OUTPUT = np.array(OUTPUT).T
+        
+    return OUTPUT
+    
 
 def same_day_rinex_check(rinex1,rinex2):
     if os.path.basename(rinex1)[4:7] == os.path.basename(rinex2)[4:7]:
@@ -328,10 +499,6 @@ def rinex_start_end(input_rinex_path,interval_out=False,
         First, las epoches and interval if asked.
 
     """
-    
-    
-    
-
 
     #une liste d'epochs en début et fin de fichier
     #=> en trouver le min et le max
@@ -367,14 +534,14 @@ def rinex_start_end(input_rinex_path,interval_out=False,
         last_epoch = last_epoch.replace(tzinfo=dateutil.tz.tzutc())
 
     if verbose:
-        print("first & last epochs : " , first_epoch , last_epoch)
+        log.info("first & last epochs: %s %s" , first_epoch , last_epoch)
     if not interval_out:
         return first_epoch , last_epoch
     else:
         interv_lis = np.diff(epochs_list)
         interv_lis = [e.seconds + e.microseconds * 10**-6 for e in interv_lis]
         interval   = utils.most_common(interv_lis)
-        print("interval : " , interval , last_epoch)
+        log.info("interval, last epoch: %s %s" , interval , last_epoch)
 
         #return interv_lis , epochs_list
         return first_epoch , last_epoch , interval
@@ -561,7 +728,7 @@ def rinex_spliter(input_rinex_path,output_directory,stat_out_name='',
     last_date = dt.datetime(last_epoch.year,last_epoch.month,
                                   last_epoch.day,last_epoch.hour)+dt.timedelta(hours=1)
 
-    print("first & last dates (truncated) : " , first_date , last_date)
+    log.info("first & last dates (truncated): %s %s" , first_date , last_date)
 
     time_interval = utils.get_interval(first_date,last_date,
                                          dt.timedelta(hours=interval_size))
@@ -573,7 +740,7 @@ def rinex_spliter(input_rinex_path,output_directory,stat_out_name='',
     for i,curr_date in enumerate(time_interval):
 
         if shift != 0:
-            print('WARN : rinex_spliter : shifted mode on, be careful !!!')
+            log.warning('shifted mode on, be careful !!!')
 
 
         if bool(shift) and i != 0:
@@ -601,17 +768,17 @@ def rinex_spliter(input_rinex_path,output_directory,stat_out_name='',
         p = subprocess.Popen('',executable='/bin/bash', stdin=subprocess.PIPE , stdout=subprocess.PIPE , stderr=subprocess.PIPE)
         # - 1/3600. # one_sec2h
         command = teqc_cmd  + ' -O.mo ' + stat_out_name.upper() +' -st ' +  curr_date.strftime('%y%m%d%H%M%S') + ' +dh ' + str(interval_size_ope) + ' ' + input_rinex_path
-        print(command)
+        log.info(command)
         rinex_out_name = stat_out_name + curr_date.strftime('%j') + rnx_interval_ext + curr_date.strftime('%y') + 'o'
         err_log_name = curr_date.strftime('%j') + rnx_interval_ext + "err.log"
-        print(rinex_out_name)
+        log.info(rinex_out_name)
         stdout,stderr = p.communicate( command.encode() )
         std_file = open(rinex_out_name, "w")
         std_file.write(stdout.decode("utf-8"))
         std_file.close()
         if stderr:
-            print(err_log_name + " is not empty, must be checked !")
-            print(stderr.decode("utf-8"))
+            log.warning(err_log_name + " is not empty, must be checked !")
+            log.info(stderr.decode("utf-8"))
             err_file = open(err_log_name, "w")
             err_file.write(stderr.decode("utf-8"))
             err_file.close()
@@ -664,7 +831,7 @@ def rinex_spliter_gfzrnx(input_rinex_path,
     last_date = dt.datetime(last_epoch.year,last_epoch.month,
                                   last_epoch.day,last_epoch.hour)+dt.timedelta(hours=1)
     
-    print("first & last dates (truncated) : " , first_date , last_date)
+    log.info("first & last dates (truncated): %s %s" , first_date , last_date)
     
     time_interval = utils.get_interval(first_date,last_date,
                                          dt.timedelta(hours=interval_size_hour))
@@ -676,7 +843,7 @@ def rinex_spliter_gfzrnx(input_rinex_path,
     for i,curr_date in enumerate(time_interval):
     
         if shift != 0:
-            print('WARN : rinex_spliter : shifted mode on, be careful !!!')
+            log.warning('shifted mode on, be careful !!!')
     
     
         if bool(shift) and i != 0:
@@ -710,7 +877,7 @@ def rinex_spliter_gfzrnx(input_rinex_path,
         
         # - 1/3600. # one_sec2h
         command = gfzrnx_cmd + ' -finp ' + input_rinex_path + ' -fout ' + os.path.join(output_directory,output_name)  + ' -site ' + stat_out_name.upper() +' -epo_beg ' +  curr_date.strftime('%Y%m%d_%H%M%S') + ' --duration ' + str(interval_size_ope) + ' ' + custom_cmds
-        print(command)
+        log.info(command)
         
         #rinex_out_name = stat_out_name + curr_date.strftime('%j') + rnx_interval_ext + curr_date.strftime('%y') + 'o'
         std_log_name = curr_date.strftime('%j') + rnx_interval_ext + "err.log"   
@@ -723,8 +890,8 @@ def rinex_spliter_gfzrnx(input_rinex_path,
         std_file.close()
         
         if stderr:
-            print(err_log_name + " output:")
-            print(stderr.decode("utf-8"))
+            log.info(err_log_name + " output:")
+            log.info(stderr.decode("utf-8"))
             err_file = open(err_log_name, "w")
             err_file.write(stderr.decode("utf-8"))
             err_file.close()
@@ -773,7 +940,7 @@ def teqc_qc(rinex_path,quick_mode=False,optional_args=''):
 
     kommand = " ".join(("teqc" , qcmode , optional_args , rinex_path))
 
-    print(kommand)
+    log.info(kommand)
 
     proc = subprocess.Popen(kommand, shell=True,
                             stdout=subprocess.PIPE,executable='/bin/bash')
@@ -783,7 +950,7 @@ def teqc_qc(rinex_path,quick_mode=False,optional_args=''):
         os.remove(rinex_path_work)
 
     if status:
-        print("ERR : teqc qc : crash for " + rinex_path + ", code " + str(proc.poll()))
+        log.error("crash for " + rinex_path + ", code " + str(proc.poll()))
         return None
 
     output = proc.stdout.read()
@@ -808,21 +975,21 @@ def rinex_renamer(input_rinex_path,output_directory,stat_out_name='',remove=Fals
     rnx_interval_ext = rinex_session_id(first_epoch,last_epoch) + '.'
     rinex_out_name = stat_out_name + first_epoch.strftime('%j') + rnx_interval_ext + first_epoch.strftime('%y') + 'o'
 
-    print(rinex_out_name)
+    log.info(rinex_out_name)
 
     output_rinex_path = os.path.join(out_dir,rinex_out_name)
 
     if input_rinex_path != output_rinex_path:
-        print("INFO : copy of ", input_rinex_path , ' to ' , output_rinex_path)
+        log.info("copy of " + input_rinex_path + ' to ' + output_rinex_path)
         shutil.copy(input_rinex_path,output_rinex_path)
 
         if remove and os.isfile(output_rinex_path) :
-            print("INFO : removing " , input_rinex_path)
+            log.info("removing " , input_rinex_path)
             os.remove(input_rinex_path)
     else:
-        print("INFO : " , input_rinex_path)
-        print("and", output_rinex_path ,"are the same file")
-        print("nothing's done ...")
+        log.info(input_rinex_path)
+        log.info("and " + output_rinex_path + " are the same file")
+        log.info("nothing's done ...")
 
     return output_rinex_path
 
