@@ -31,6 +31,11 @@ import subprocess
 
 #### geodeZYX modules
 from geodezyx import utils
+
+#### Import the logger
+import logging
+log = logging.getLogger(__name__)
+
 ##########  END IMPORT  ##########
 
 
@@ -39,6 +44,49 @@ from geodezyx import utils
 ### SHELL LIKE FCTS
 #################
 
+
+
+def subprocess_frontend(cmd_in,
+                        save_log=False,
+                        log_dir=None,
+                        log_name_out="out.log",
+                        log_name_err="err.log",
+                        logname_timestamp=False):
+    
+    
+    now = utils.get_timestamp()
+    
+    process1 = subprocess.run([cmd_in],
+                              capture_output=True,
+                              text=True,
+                              shell=True)
+    
+    process1_stdout = process1.stdout.strip()
+    process1_stderr = process1.stderr.strip()
+    
+    if save_log:
+        
+        if not log_dir:
+            logdir = os.getcwd()
+            
+        if logname_timestamp:
+            prefix = now + "_" 
+        else:
+            prefix = ""
+        
+        out_file = open(log_dir + "/" + prefix + log_name_out, "a+")
+        err_file = open(log_dir + "/" + prefix + log_name_err, "a+")
+    
+        out_file.write(process1_stdout)
+        err_file.write(process1_stderr)
+    
+        out_file.close()
+        err_file.close()
+    
+    return process1,process1_stdout,process1_stderr
+
+
+
 def tail(filename, count=1, offset=1024):
     """
     A more efficent way of getting the last few lines of a file.
@@ -103,9 +151,11 @@ def grep(file_in,search_string,only_first_occur=False,
     if file_in[-2:] in ("gz","GZ"): ### cand handle gziped files 
         File = gzip.open(file_in, "r+")
         Lines = [e.decode('utf-8') for e in File]
+        File.close()
     else:
         File = open(file_in,encoding = "ISO-8859-1")
         Lines = File.readlines()
+        File.close()
         
     for iline , line in enumerate(Lines):
         trigger = False
@@ -159,7 +209,7 @@ def egrep_big_string(regex,bigstring,only_first_occur=False):
     if len(matching_line_list) == 1:
         return matching_line_list[0]
     elif len(matching_line_list) == 0:
-        print("WARN: nothing found... check the input args: 1-regex, 2-bigstring")
+        log.warning("nothing found... check the input args order: 1-regex, 2-bigstring")
         return ''
     
     elif only_first_occur:
@@ -265,7 +315,7 @@ def find_recursive(parent_folder , pattern,
         Sort results
         
     case_sensitive : bool
-        Case sensitve or not
+        Case sensitve or not. If False, the pattern *must* be a regex
         
     extended_file_stats : bool
         if True, returns the stats of the files
@@ -300,6 +350,7 @@ def find_recursive(parent_folder , pattern,
     if case_sensitive:
         for root, dirnames, filenames in os.walk(parent_folder):
             for filename in fnmatch.filter(filenames, pattern):
+            #for filename in fnmatch.fnmatch(filenames, pattern):
                 matches.append(os.path.join(root, filename))
     else: # not case sensitive, use a regex
         for root, dirnames, filenames in os.walk(parent_folder):
@@ -307,7 +358,7 @@ def find_recursive(parent_folder , pattern,
                 try:
                     bool_match = re.search(pattern, filename, re.IGNORECASE)
                 except Exception as e:
-                    print("ERR : if case_sensitive = False, pattern have to be a REGEX (and not only a simple wildcard)")
+                    log.error("if case_sensitive = False, pattern have to be a REGEX (and not only a simple wildcard)")
                     raise e
                     
                 if bool_match:
@@ -323,16 +374,16 @@ def find_recursive(parent_folder , pattern,
             try:
                 stat = os.stat(f)
             except FileNotFoundError:
-                print("WARN: file not found",f)
+                log.warning("file not found %s",f)
                 continue
                 
             matches_ext.append((f,stat))
         matches = matches_ext
         
     if warn_if_empty and len(matches) == 0:
-        print("WARN:find_recursive: no files found! check parent folder and pattern")
-        print(parent_folder)
-        print(pattern)
+        log.warning("no files found! check parent folder and pattern")
+        log.info("Parent folder  :%s",parent_folder)
+        log.info("Pattern        :%s",pattern)
                 
     return matches
 
@@ -346,9 +397,9 @@ def glob_smart(dir_path,file_pattern=None,verbose=True):
     
     if verbose:
         if not outlist:
-            print("WARN : no file(s) found as" , dir_path_ok)
+            log.warning("no file(s) found as %s" , dir_path_ok)
         else:
-            print("INFO :" , len(outlist),"file(s) found as", dir_path_ok)
+            log.info("%d file(s) found as %s", len(outlist), dir_path_ok)
             
     return outlist
 
@@ -398,7 +449,7 @@ def insert_str_in_file_if_line_contains(file_path,str_to_insert,
                     break
                 
         if only_first_occur and pattern_found:
-            print("break at line " , ilin)
+            log.info("break at line " , ilin)
             break
                 
     f = open(file_path, "w")
@@ -410,7 +461,7 @@ def insert_str_in_file_if_line_contains(file_path,str_to_insert,
     
 def uncompress(pathin,dirout = '', opts='-f'):
     if not os.path.isfile(pathin):
-        print('ERR : uncompress : ', pathin , ' dont exist !!!')
+        log.error('uncompress : %s doesnt exist !!!', pathin)
         return None
     komand = 'uncompress ' + opts + ' ' + pathin
     subprocess.call([komand], shell=True)
@@ -433,7 +484,7 @@ def remove_dir(directory):
     if os.path.exists(directory):
         shutil.rmtree(directory)
     else:
-        print('WARN : remove_dir : ' , directory , ' dont exists ... skip ...')
+        log.warning('%s dont exists ... skip ...',directory)
     return None
 
 def walk_dir(parent_dir):
@@ -454,7 +505,7 @@ def walk_dir(parent_dir):
     return files_list , dirs_list
 
 def fileprint(output,outfile):
-    print(output)
+    log.debug(output)
     with open(outfile, "a") as f:
         f.write("{}\n".format(output))
     return None
@@ -462,15 +513,20 @@ def fileprint(output,outfile):
 
 
 
-def write_in_file(string_to_write,outdir,outname,ext='.txt',encoding='utf8'):
+def write_in_file(string_to_write,outdir_or_outpath,
+                  outname="",ext='.txt',encoding='utf8'):
     """
-
     encoding : utf8, latin_1
     https://docs.python.org/3/library/codecs.html#standard-encodings
     
     check the following commented old version if troubles
     """
-    outpath = os.path.join(outdir,outname + ext)
+    
+    if outname:
+        outpath = os.path.join(outdir_or_outpath,outname + ext)
+    else:
+        outpath = outdir_or_outpath
+        
     F = open(outpath,'w+',encoding=encoding)
     F.write(string_to_write)
     F.close()
